import { RegionType, ApiCredentials } from '@tencent-serverless-framework/common';
import { Client } from 'tencentcloud-sdk-nodejs/tencentcloud/services/vpc/v20170312/vpc_client';
import { CreateSubnetRequest, CreateVpcRequest, ModifySubnetAttributeRequest, ModifyVpcAttributeRequest } from 'tencentcloud-sdk-nodejs/tencentcloud/services/vpc/v20170312/vpc_models';
import { VpcDeployInputs, VpcRemoveInputs, VpcDeployOutputs } from './interface';
export declare const t: import("i18next").TFunction;
/** 腾讯云私有网络 （Vpc）for serverless component */
export declare class Vpc {
    /** 地域 */
    region: RegionType;
    /** 鉴权信息 */
    credentials: ApiCredentials;
    /** sdk 实例 */
    client: Client;
    /**
     * 构造函数
     *
     * @param credentials 认证信息
     * @param region 地域信息
     */
    constructor(credentials?: ApiCredentials, region?: RegionType);
    /**
     * 部署私有网络
     *
     * @param inputs 输入
     * @returns 输出
     */
    deploy(inputs: VpcDeployInputs): Promise<VpcDeployOutputs>;
    /**
     * 移除私有网络
     *
     * @param inputs 输入
     * @returns 成功时返回 {}
     */
    remove(inputs: VpcRemoveInputs): Promise<{}>;
    /**
     * 获取 VPC 详情
     *
     * @param vpcId VPC ID
     * @returns VPC 详情
     */
    getVpcDetail(vpcId: string): Promise<import("tencentcloud-sdk-nodejs/tencentcloud/services/vpc/v20170312/vpc_models").Vpc | null>;
    /**
     * 获取子网详情
     *
     * @param subnetId 子网 Id
     * @returns 子网详情
     */
    getSubnetDetail(subnetId: string): Promise<import("tencentcloud-sdk-nodejs/tencentcloud/services/vpc/v20170312/vpc_models").Subnet | null>;
    /**
     * 创建 Vpc
     *
     * @param req 请求体
     * @returns 创建的 VPC
     */
    createVpc(req: CreateVpcRequest): Promise<import("tencentcloud-sdk-nodejs/tencentcloud/services/vpc/v20170312/vpc_models").Vpc | undefined>;
    /**
     * 修改 Vpc
     *
     * @param req 请求体
     * @returns 创建的 VPC
     */
    modifyVpc(req: ModifyVpcAttributeRequest): Promise<void>;
    /**
     * 删除 Vpc
     *
     * @param vpcId VPC ID
     */
    deleteVpc(vpcId: string): Promise<void>;
    /**
     * 创建子网
     *
     * @param req 请求体
     * @returns 创建的子网
     */
    createSubnet(req: CreateSubnetRequest): Promise<import("tencentcloud-sdk-nodejs/tencentcloud/services/vpc/v20170312/vpc_models").Subnet | undefined>;
    /**
     * 修改子网
     *
     * @param req 请求体
     */
    modifySubnet(req: ModifySubnetAttributeRequest): Promise<void>;
    /**
     * 删除子网
     *
     * @param subnetId 子网 ID
     */
    deleteSubnet(subnetId: string): Promise<void>;
}
