import { RegionType } from '@tencent-serverless-framework/common';
import { Tag } from 'tencentcloud-sdk-nodejs/tencentcloud/services/vpc/v20170312/vpc_models';

/** 部署私有网络输入 */
export interface VpcDeployInputs {
  /**
   * 关联实例ID所属大区，例如：ap-guangzhou。
   */
  region?: RegionType;
  /**
   * 可用区，如：ap-guangzhou-2
   */
  zone: string;
  /**
   * vpc名称，最大长度不能超过60个字节。
   */
  vpcName: string;
  /**
   * 子网名称，最大长度不能超过60个字节。
   */
  subnetName: string;

  /**
   * vpc的cidr，仅能在10.0.0.0/16，172.16.0.0/16，192.168.0.0/16这三个内网网段内。
   */
  cidrBlock?: string;

  /**
   * 是否开启组播。true: 开启, false: 不开启。
   */
  enableMulticast?: 'true' | 'false';
  /**
   * DNS地址，最多支持4个。
   */
  dnsServers?: string[];
  /**
   * DHCP使用的域名。
   */
  domainName?: string;
  /**
   * 指定绑定的标签列表，例如：[{"Key": "city", "Value": "shanghai"}]。
   */
  tags?: Tag[];
  /**
   * 指定绑定的标签列表，例如：[{"Key": "city", "Value": "shanghai"}]
   */
  subnetTags?: Tag[];
  /**
   * 是否开启广播。
   */
  enableSubnetBroadcast?: 'true' | 'false';
  /**
   * `VPC`实例`ID`。形如：`vpc-6v2ht8q5`
   */
  vpcId?: string;
  /**
   * 子网实例ID。形如：subnet-pxir56ns。
   */
  subnetId?: string;
}

/** 私有网络部署输出 */
export interface VpcDeployOutputs {
  /**
   * 关联实例ID所属大区，例如：ap-guangzhou。
   */
  region?: RegionType;
  /**
   * 可用区，如：ap-guangzhou-2
   */
  zone: string;
  /**
   * `VPC`实例`ID`。形如：`vpc-6v2ht8q5`
   */
  vpcId?: string;
  /**
   * vpc名称，最大长度不能超过60个字节。
   */
  vpcName: string;
  /**
   * 子网实例ID。形如：subnet-pxir56ns。
   */
  subnetId?: string;
  /**
   * 子网名称，最大长度不能超过60个字节。
   */
  subnetName: string;
}

/** 移除私有网络输入 */
export interface VpcRemoveInputs {
  /**
   * `VPC`实例`ID`。形如：`vpc-6v2ht8q5`
   */
  vpcId: string;
  /**
   * 子网实例ID。形如：subnet-pxir56ns。
   */
  subnetId: string;
}
