import { VpcDeployInputs } from '../src/interface';
import { Vpc } from '../src';

describe('Vpc', () => {
  const credentials = {
    SecretId: process.env.TENCENT_SECRET_ID,
    SecretKey: process.env.TENCENT_SECRET_KEY,
  };
  const inputs: VpcDeployInputs = {
    region: process.env.REGION,
    zone: process.env.ZONE!,
    vpcName: 'serverless-test',
    subnetName: 'serverless-test',
    cidrBlock: '10.0.0.0/16',
    enableSubnetBroadcast: 'true',
  };
  const vpc = new Vpc(credentials, process.env.REGION);

  test('should not get vpc detail (not exist)', async () => {
    try {
      const res = await vpc.getVpcDetail('vpc-notexists');
      expect(res).toBeNull();
    } catch (e) {
      console.log(e.message);
      // expect(e.code).toBe('LimitExceeded');
      expect(e.message).toBe(undefined);
    }
  });

  test('should success deploy a vpc failed (cidr not provide)', async () => {
    try {
      await vpc.deploy({
        ...inputs,
        cidrBlock: undefined,
      });
    } catch (e) {
      console.log(e.message);
      // expect(e.code).toBe('LimitExceeded');
      expect(e.type).toBe('PARAMETER_VPC');
    }
  });

  test('should success deploy a vpc', async () => {
    try {
      const res = await vpc.deploy(inputs);
      expect(res).toEqual({
        region: process.env.REGION,
        zone: process.env.ZONE,
        vpcId: expect.stringContaining('vpc-'),
        vpcName: 'serverless-test',
        subnetId: expect.stringContaining('subnet-'),
        subnetName: 'serverless-test',
      });

      inputs.vpcId = res.vpcId;
      inputs.subnetId = res.subnetId;
    } catch (e) {
      console.warn(e.message);
      // expect(e.code).toBe('LimitExceeded');
      expect(e.message).toBe(undefined);
    }
  });

  test('should success update a vpc', async () => {
    try {
      const res = await vpc.deploy({
        ...inputs,
        enableMulticast: 'true',
        enableSubnetBroadcast: 'false',
      });
      expect(res).toEqual({
        region: process.env.REGION,
        zone: process.env.ZONE,
        vpcId: expect.stringContaining('vpc-'),
        vpcName: 'serverless-test',
        subnetId: expect.stringContaining('subnet-'),
        subnetName: 'serverless-test',
      });

      inputs.vpcId = res.vpcId;
      inputs.subnetId = res.subnetId;
    } catch (e) {
      console.log(e.message);
      // expect(e.code).toBe('LimitExceeded');
      expect(e.message).toBe(undefined);
    }
  });

  test('should success remove a vpc', async () => {
    if (inputs.vpcId) {
      await vpc.remove({
        vpcId: inputs.vpcId,
        subnetId: inputs.subnetId!,
      });
      const vpcDetail = await vpc.getVpcDetail(inputs.vpcId);
      const subnetDetail = await vpc.getSubnetDetail(inputs.subnetId!);

      expect(vpcDetail).not.toBeTruthy();
      expect(subnetDetail).not.toBeTruthy();
    } else {
      expect(true).toBe(true);
    }
  });
});
